@@ -18,6 +18,16 @@
 #' setting the file path for the current session with
 #' `options(finbif_cache_path = "path/to/cache")`.
 #'
+#' @section Using database caching:
+#' Caching can also be done using a database. Using a database for caching
+#' requires the packages `DBI`, `blob` and a database backend package such as
+#' `RSQLite` to be installed. To use the database for caching simply pass the
+#' connection objected created with `DBI::dbConnect` to the `finbif_cache_path`
+#' option (e.g.,
+#' `db <- DBI::dbConnect(RSQLite::SQLite(), "my-db.sqlite"); `
+#' `options(finbif_cache_path = db)`
+#' ).
+#'
 #' @section Clearing the cache:
 #' The cache files can deleted `finbif_clear_cache()`.
 #'
@@ -28,24 +38,46 @@ NULL
 
 cache_location <- new.env()
 
+#' @noRd
+
 get_cache <- function(hash) {
 
-  hash_exists <- exists(hash, envir = cache_location)
+  data <- NULL
 
-  if (hash_exists) {
+  if (exists(hash, envir = cache_location)) {
 
-    get(hash, envir = cache_location)
+    obj <- get(hash, envir = cache_location)
+
+    valid <- TRUE
+
+    if (!isTRUE(obj[["swagger"]])) {
+
+      valid <- cache_is_valid(obj[["timeout"]], obj[["created"]])
+
+    }
+
+    if (valid) {
+
+      data <- obj[["data"]]
+
+    } else {
+
+      remove(list = hash, envir = cache_location)
+
+    }
 
   }
 
+  data
+
 }
 
+#' @noRd
+
 set_cache <- function(obj) {
 
-  hash <- obj[["hash"]]
+  obj[["created"]] <- Sys.time()
 
-  data <- obj[["data"]]
-
-  assign(hash, data, envir = cache_location)
+  assign(obj[["hash"]], obj, envir = cache_location)
 
 }
